pub trait FixedScale {
const SCALE: u64;
}Expand description
Trait for a fixed scale. It only has one associated constant that must be implemented:
SCALE, which defines the place of the decimal point.
Required Associated Constants
Dyn Compatibility
This trait is not dyn compatible.
In older versions of Rust, dyn compatibility was called "object safety".